Hans Leidekker : usp10: Fix a test to not rely on uninitialized memory.

Alexandre Julliard julliard at winehq.org
Fri Nov 9 07:44:11 CST 2007


Module: wine
Branch: master
Commit: 66c6b84ff090cb2a6a19cbc61d2be8f693d3d236
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=66c6b84ff090cb2a6a19cbc61d2be8f693d3d236

Author: Hans Leidekker <hans at it.vu.nl>
Date:   Thu Nov  8 19:18:22 2007 +0100

usp10: Fix a test to not rely on uninitialized memory.

---

 dlls/usp10/tests/usp10.c |    5 +++--
 1 files changed, 3 insertions(+), 2 deletions(-)

diff --git a/dlls/usp10/tests/usp10.c b/dlls/usp10/tests/usp10.c
index 1aba6db..73615de 100644
--- a/dlls/usp10/tests/usp10.c
+++ b/dlls/usp10/tests/usp10.c
@@ -337,10 +337,11 @@ static void test_ScriptGetFontProperties(HDC hdc)
     ok( hr == E_INVALIDARG, "(hdc,&psc,NULL), expected E_INVALIDARG, got %08x\n", hr);
     ok( psc == NULL, "Expected psc to be NULL, got %p\n", psc);
 
     /* Pass an uninitialized sfp */
     psc = NULL;
+    sfp.cBytes = sizeof(SCRIPT_FONTPROPERTIES) - 1;
     hr = ScriptGetFontProperties(hdc,&psc,&sfp);
-    ok( hr == E_INVALIDARG, "(hdc,&psc,&sfp) partly uninitialized, expected E_INVALIDARG, got %08x\n", hr);
+    ok( hr == E_INVALIDARG, "(hdc,&psc,&sfp) invalid, expected E_INVALIDARG, got %08x\n", hr);
     ok( psc != NULL, "Expected a pointer in psc, got NULL\n");
     ScriptFreeCache(&psc);
     ok( psc == NULL, "Expected psc to be NULL, got %p\n", psc);
@@ -337,10 +337,11 @@ static void test_ScriptGetFontProperties(HDC hdc)
     ok( psc == NULL, "Expected psc to be NULL, got %p\n", psc);
 
-    /* Pass an uninitialized sfp */
+    /* Pass an invalid sfp */
     psc = NULL;




More information about the wine-cvs mailing list